==> haskell-tasty-th-0.1.7-446-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-7HxrNBZmurRHJFzGvPAXH1
key:                  tasty-th-0.1.7-7HxrNBZmurRHJFzGvPAXH1
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  f2dcb717c891854d17304e9dbdef4f86
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-th-0.1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-th
hs-libraries:         HStasty-th-0.1.7-7HxrNBZmurRHJFzGvPAXH1
depends:
    base-4.17.2.1 haskell-src-exts-1.23.1-9Ig3uW2SwL3HLuRAMfCXfZ
    tasty-1.5-FRQtZsdenVIBoQGCChJ79f template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-th-0.1.7-448-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-sALUuxQKIFHByg21XuzAu
key:                  tasty-th-0.1.7-sALUuxQKIFHByg21XuzAu
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  941037c5d7e7108ff81c1f25af1b6e46
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-th-0.1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-th
hs-libraries:         HStasty-th-0.1.7-sALUuxQKIFHByg21XuzAu
depends:
    base-4.17.2.1 haskell-src-exts-1.23.1-7sthXiRAJYP1gpRCFZXGzT
    tasty-1.5-E1wR27wymYK20HA20y89Ru template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
